#
# spec file for package ghex
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define ghex_abi   4
%define so_ver     1
%define so_ver_ext 0
%define soname libgtkhex-%{ghex_abi}-%{so_ver}

Name:           ghex
Version:        46.1
Release:        1.3
Summary:        GNOME Binary Editor
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://wiki.gnome.org/Apps/Ghex
Source:         %{name}-%{version}.tar.zst

BuildRequires:  fdupes
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(atk) >= 1.0.0
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.31.10
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
# Obsoletes libgtkhex-4-0 can be dropped when SLED/Leap 15.5 is out of support
Obsoletes:      libgtkhex-4-0 < %{version}

%description
GHex allows the user to load data from any file and to view and edit it
in either hex or ASCII. It is a must for anyone playing games that use
a non-ASCII format for saving.

%package -n %{soname}
Summary:        GNOME Binary Editor -- Library
Group:          System/Libraries

%description -n %{soname}
GHex allows the user to load data from any file and to view and edit it
in either hex or ASCII. It is a must for anyone playing games that use
a non-ASCII format for saving.

%package devel
Summary:        GNOME Binary Editor -- Development Files
Group:          Development/Libraries/GNOME
Requires:       %{soname} = %{version}

%description devel
GHex allows the user to load data from any file and to view and edit it
in either hex or ASCII. It is a must for anyone playing games that use
a non-ASCII format for saving.

%package -n typelib-1_0-Hex-%{ghex_abi}
Summary:        Introspection bindings for ghex
Group:          System/Libraries

%description -n typelib-1_0-Hex-%{ghex_abi}
This package provides introspection bindings for ghex.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%suse_update_desktop_file -r org.gnome.GHex GNOME Utility Editor
%find_lang %{name} ghex-%{ghex_abi}-%{so_ver}.%{so_ver_ext}.lang %{?no_lang_C}
%fdupes -s %{buildroot}%{_datadir}

%ldconfig_scriptlets -n %{soname}

%files
%license COPYING
%doc README.md COPYING-DOCS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/ghex
%{_datadir}/metainfo/org.gnome.GHex.appdata.xml
%{_datadir}/applications/org.gnome.GHex.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.GHex.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.GHex*
# Not split out as they are private to ghex
%dir %{_libdir}/gtkhex-%{ghex_abi}.%{so_ver_ext}
%{_libdir}/gtkhex-%{ghex_abi}.%{so_ver_ext}/*.so

%files -n %{soname}
%{_libdir}/libgtkhex-%{ghex_abi}.so.*

%files -n typelib-1_0-Hex-%{ghex_abi}
%{_libdir}/girepository-1.0/Hex-%{ghex_abi}.typelib

%files devel
%{_includedir}/gtkhex-%{ghex_abi}/
%{_libdir}/libgtkhex-%{ghex_abi}.so
%{_libdir}/pkgconfig/gtkhex-%{ghex_abi}.pc
%{_datadir}/gir-1.0/Hex-%{ghex_abi}.gir

%files lang -f %{name}-%{ghex_abi}-%{so_ver}.%{so_ver_ext}.lang

%changelog
* Fri Nov 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.1:
  + main: fix GdkDisplay access before init.
  + Updated translations.
* Fri Mar 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + widget: Fade zeroes in the hex display.
  + data: add 'hexadecimal' keyword to .desktop file.
  + appdata: Remove none OARS tags.
  + appdata: Update appdata.
  + appwin: Don't let AdwTabView trample over shortcuts.
  + lib: Fix PANGO_COLOR_FROM_FLOAT macro.
  + docs: GI tweaks and fixes.
  + lib/app: Initial support for marks.
  + help: Add marks section.
  + i18n: Remove domain that prevented use of translations.
  + appwin: Allow dropping multiple files.
  + widget/doc: Set widget busy state while file is mid-save.
  + Code and documentation cleanups.
  + Updated translations.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + GObject property getter fixes.
  + buf-malloc/mmap: Implement GObject 'file' property getter
    properly.
  + hex-buf/doc: Clarify GI transfer annotations.
  + hex-doc/buf: Support opening zero-length files.
  + hex-buf-iface: More appropriate messages when selecting
    backend.
  + hex-doc: Allow setting HEX_BUFFER env var to specify default
    backend.
  + Remove almost all remaining GtkDialog use.
  + about: port dialog to libadwaita.
  + Update POTFILES.in.
  + chartable: Port to GtkColumnView.
  + gtkhex: Local variables in switch statement should be in own
    scope (ie, fix clang build issues).
  + appwin: Mark error message string properly translatable.
- Convert to source service for easier updating.
* Tue Nov 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + gtkhex: Local variables in switch statement should be in own
    scope (ie, fix clang build issues)
  + appwin: Mark error message string properly translatable
* Wed Oct 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + docs: fix introspection compiler warning
  + help: Add section on geometry
  + Updated translations.
* Tue Aug 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + hex-dialog: Prevent decimal display widgets from getting
    truncated.
  + widget: Make paste overwrite when not in insert mode.
* Thu Aug 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Mark three strings translatable.
  + ui:
  - Add tooltip to the main menu to comply with GNOME HIG.
  - Add shortcut for preferences and fix help shortcut
    description.
  + appwin: Ensure HexStatusbar is registered before initting
    template.
  + Updated translations.
* Thu Apr 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Update application screenshots to version 44.
  + hex-dialog: Prevent decimal display widgets from getting
    truncated.
* Sat Apr  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Updated translations.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Updated translations.
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + widget: Add context menu popover to set custom geometry.
  + appwin: Accept drag 'n' drop for files.
  + Updated translations.
* Thu Feb  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.alpha:
  + HexWidget: Only alter payload length in insert mode.
  + help: Remove ducktype and update to reflect change in delete
    behaviour.
  + Updated translations.
* Thu Feb  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Updated translations.
* Wed Oct  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Wed Sep 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc:
  + appwin:
  - Properly call gettext on string marked for translation
  - Support dragging tabs to new window
  + build: Added option to generate VALA vapi
  + hex-doc:
  - Add sanity checks to _get_buffer and _get_file in public API
  - Fix assertion check in hex_document_write_to_file_async
  - Fix replacing bytes over a gap
  + icons: Make document-modified-symbolic a resource
  + Minor cleanups
  + preferences:
  - Vertically center font buttons
  - Vertically center spin button
  + widget: Don't drop additional reference on menu model
  + Updated translations.
- Drop 8927f9a7.patch: Fixed upstream.
* Mon Sep 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 8927f9a7.patch: icons: Make document-modified-symbolic a
  resource.
* Fri Aug  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add ghex_abi and so_ver_ext define and set to 4 and 0 following
  upstream changes and set so_ver define to 1. Further, add a
  soname define, and set it to libgtkhex-%%%%{ghex_abi}-%%%%{so_ver},
  ease future updates.
- Move gtkhex-*/*.so to main package, and obsolete older versions
  of libgtkhex-* from the same. These private so files (plugins)
  should never have been packaged in the shared library package, so
  now we have to clean up our previous sins.
* Thu Jul  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.alpha:
  + Port to libadwaita, and fix UI papercuts that stood out more
    thereafter.
  + Introduce custom statusbar with monospace support
  + HexWidget:
  - Add API to show/hide specific columns.
  - Disallow keyboard shortcuts to activate hidden panes.
  - Support PRIMARY selection.
  + Find and Replace improvements:
  - Support options for case-sensitivity, regex.
  - Choose visibility of hex/ascii/both in find/replace dialogs.
  - Show number of replacements with Replace All.
  + New backend: HexBufferDirect, and support for reading/writing
    block devices.
  + Load default backend plugins more intelligently.
  + docs: document slight change in hex_buffer_util_new behaviour
    when a non-existent plugin is requested (return NULL instead of
    falling back to malloc).
  + chartable: ESC should close dialog.
  + Animate opening and closing of find/replace and conversions
    panes.
  + paste-special: Move space-delim hex pairs to UTF8 list.
  + build: Fix incorrect soname numbering; split resources between
    app and library.
  + docs: document expanded HexDocument and HexWidget APIs.
  + Error handling improvements and code cleanups.
* Wed Jun 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.3:
  + main: Hotfix to workaround gtk #4880 (affects Save As dialogs
    on X11 primarily).
  + config: Add GNOME 42+ compatibility for dark mode, and fetch
    dark settings from portal if possible.
  + widget: Properly update highlights upon resize.
  + find-replace: Remove spurious g_object_ref() call.
* Wed Apr 27 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.2:
  + hexwidget: Fix redraw on keyboard focus change.
  + Updated translations.
* Wed Apr 20 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 42.1:
  + appwin: Fix hamburger checkmark for Find & Replace dialog.
  + appwin: Fix markup on tab-close dialogs.
  + findreplace: Mark two a11y strings translatable.
  + Updated translations.
* Wed Apr  6 2022 Emily Gonyer <emilyyrose@gmail.com>
- Updte to version 42.0:
  + appwindow: Fix format string warnings.
  + paste-special: properly copy hex pairs for higher-order bytes.
  + doc: build devhelp index.
  + build: Use gnome.post_install.
  + docs: Remove unused translated ghex_window_open.png image
    files.
  + help: fix typo etc in help.
  + build: Split versioning scheme for app and lib.
  + gtkhex: Segregate mmap backend as plugin.
* Mon Jan 10 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.beta.1:
  + HexWidget: Implement Home and End keybindings.
  + HexWidget: fix offsets redraw issue.
  + appwin: fix function order when opening invalid file.
  + help: initial rewrite to mallard and update for GHex4.
  + help: add support for static HTML help.
  + help: fix typos.
* Thu Dec 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.alpha.2:
  + lib:
  - Rename GtkHex to HexWidget
  - Make some raw structs into boxed types for GI
  - Rework data types so that we have a minimum cursor pos and
    file size that works with files larger than 2 GB
  + lib/docs: Initial API documentation (gi-docgen required)
  + lib/app: asynchronous APIs for many operations, and integrate
    with application features
  + GUI/settings: support quadwords grouping
  + Error handling improvements
  + HexBufferIface: Standardize on GFile when it comes to file
    handling
  + HexWidget:
  - Rework the "busy" spinner to be at the widget level
  - Restore hex_widget_set_geometry API
  - Dynamically sized offset column, and fix calculation of
    offset cols required
  + HexBufferMmap: improvements, fixes and optimizations
  + findreplace: watch/busy feedback and cancellable
  + converter: a11y update
  + meson:
  - Add `introspection` and `gtk_doc` options
  - Remove `experimental-mmap` option; replace with
    `buffer-backend` (with mmap being the new default, where
    supported; see meson_options.txt)
  + Various code cleanups and miscellaneous bugfixes
  + Updated translations.
- Changes from version 4.alpha.1:
  + This is the first alpha release of GHex with GTK4 support. As
    it has been substantially reworked from GHex 3.x, it will
    require some substantial testing and translation updates.
  + Visibly to the end user, some new features include:
  - More modern and up-to-date look and feel, consistent with the
    GNOME HIG.
  - Tabbed interface.
  - Dark Mode (by default, the GTK system-wide
    "prefer-dark-theme" setting is used, but can be overridden
    with a checkbox and a switch in the Preferences dialog).
  - Libadwaita colour compatibility; if you use the Adwaita theme
    and GNOME apps that utilize libadwaita, GHex will (read:
    should) match the colour scheme. libadwaita is not a planned
    dependency for GHex at this time as many of its users are GTK
    users who do not run GNOME, and I want to keep GHex's
    dependency requirements to a minimum.
  - Custom clipboard data, for less error-prone copying and
    pasting of binary data; this will fall back to plaintext when
    unavailable.
  - Copy and Paste Special dialogs, which allow you to, for
    instance, copy and paste hex pairs from GHex into other
    applications, and to paste hex pairs from other applications
    into GHex.
  + Changes: Port and rework for GTK4
  + Updated translations.
- Add pkgconfig(gi-docgen) BuildRequires, build api docs.
- Replace pkgconfig(gtk+-3.0) with pkgconfig(gtk4) BuildRequires
  following upstreams port.
- Rename libgtkhex-3-0 to libgtkhex-4-0 following soname bump.
- Add new sub package typelib-1_0-Hex-4.
- Add so_ver define and set it to 4, ease future updates.
* Sun Dec  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.41.1:
  + Add clipboard shortcuts to find/replace dialogs.
  + Updated translations.
* Fri Sep 24 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.41.0:
  + No changes, version bump only.
- Changes from version 3.41.rc:
  + Fix internal copy/paste between multiple GHex windows.
  + Install symbolic icon in correct location.
- Changes from version 3.41.beta:
  + Meson build fixes.
  + Update HACKING guide.
  + Show top 32-bits of 64-bit integers.
  + Update app icon.
  + Add padding after offset.
  + Fix cut, copy and paste behaviour.
  + Remove/rework outdated/obsolete documentation.
  + Updated translations.
- Update URL to new GNOME wiki home.
- Tweak fdupes macro call.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Jul 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.18.4:
  + Distribute extra empty space between offsets and xdisp.
  + Improve border with calculations.
  + Migrate build system to meson.
  + Add OARS metadata.
  + Update various links after bugzilla to gitlab migration.
  + Rename icons, appstream and desktop files to consistently use
    org.gnome.GHex ID.
  + Add flatpak manifest for nightly builds, enable nightly builds
    in CI.
  + Install appstream metadata to non-deprecated location.
  + Various updates to help docs.
  + Updated translations.
- Switch to meson buildsystem following upstreams port: Add meson
  BuildRequires and macros.
- Drop now obsolete intltool, translation-update-upstream
  BuildRequires and glib2_gsettings_schema_requires macro and
  conditional calling of desktop_database_post(un),
  icon_theme_cache_post(un) and glib2_gsettings_schema_post(un) in
  post(un).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 3.18.3:
  + Add Language headers to po files.
  + Unbreak build with GCC 4.
  + Updated translations.
* Tue Jun 14 2016 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix build with GCC 6.
  + Updated translations.
* Tue May 17 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Thu May 12 2016 zaitor@opensuse.org
- Update to version 3.18.1:
  + Update the AppData file to spec version 0.7+.
  + Updated translations.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Thu Oct  1 2015 zaitor@opensuse.org
- Own %%{_datadir}/icons/hicolor/512x512 and subfolders on older
  versions of openSUSE.
* Wed Sep 23 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep  2 2015 dimstar@opensuse.org
- Update to version 3.17.91:
  + Fix icon installation.
  + Update screenshot in appdata file.
- Changes from version 3.17.90:
  + Add symbolic icon.
  + Include higher resolution app icons.
  + Support decoding 64-bit integers.
  + Allow immediate clicking between gtkhex views.
  + Improve the default file name when printing to a file.
  + Updated translations.
- Drop HighContrast icon theme handling in post/postun.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.10.1:
  + Update URLs in doap and appdata files.
  + Updated translations.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Stable release, no changes from version 3.9.92.
* Wed Sep 18 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Ship an appdata file.
  + Don't use AM_GNU_GETTEXT.
  + Updated translations.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Validate the .desktop file on 'make check'.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Make it possible to resize the main window to fit smaller
    screens.
  + Updated translations.
- Drop ghex-empty-search-crash.patch: fixed upstream.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Updated translations.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + New icons for the HighContrast theme.
  + Add search keywords to the .desktop file.
  + Updated translations.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Use yelp-tools instead gnome-doc-utils.
  + Updated translations.
- Replace gtk-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams port to the new documentation infrastructure.
* Tue Feb 19 2013 sbrabec@suse.cz
- Removed obsolete ghex-empty-search-crash.patch. (bgo#473208)
* Tue Oct 16 2012 zaitor@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Thu Sep 27 2012 zaitor@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Improvements to the size allocation code in the GtkHex widget
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Port to GtkApplication
  + Remove deprecated use of GDK_THREADS_ENTER/LEAVE
  + Updated translations.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Fix drag-and-drop from file managers
  + Updated translations.
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Prepend 0x to the offset in status bar.
  + Avoid using gtk 3.4 deprecated symbols.
  + Windows build improvements.
  + Updated translations.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Updated translations.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Fix a desktop-file-validate warning about ghex.desktop.
  + Updated translations.
* Fri Mar  9 2012 dimstar@opensuse.org
- Update to version 3.3.91:
  + Store the UI definition file as resource data
  + Better experience for the "Goto Byte..." dialog
  + Various code cleanups
  + Updated translations.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Fix excessive scrolling back to cursor
  + Use maintainer mode by default
  + Remove the use of deprecated GTK+ API
  + Windows port fixes
  + Visual improvements with latest Adwaita theme
  + Updated translations.
- Stop passing --disable-schemas-install to configure: there is no
  gconf schema anymore.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.0.0:
  + Updated translations.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 2.90.2:
  + Fix endianess conversion for 64-bit floating point (bgo#625968,
    bgo#648644)
  + Update oudated FSF mailing address (bgo#656596)
  + Build system cleanups (bgo#656919)
  + Updated translations.
- Remove renaming hack of sr@Latn to sr@latin: fixed upstream.
- Stop changing Name and GenericName in .desktop file: they're
  correct upstream.
- Remove sed hack to remove Development category in .desktop file,
  and instead use -r in %%suse_update_desktop_file to replace
  existing categories. Add GNOME category too.
- Drop explicit Requires for atk-devel, gail-devel, gtk2-devel in
  devel subpackage: the right Requires will automatically be added
  the pkgconfig() way.
- Split library in libgtkhex-3-0 subpackage, to follow shared
  library packaging policy.
* Mon Aug 15 2011 dimstar@opensuse.org
- Update to version 2.90.1:
  + Port from GConf to GSettings
  + Scrolling code cleanup
  + Moved internal pkgconfig dependencies to Requires.private
  + Bugs fixed: bgo#656080, bgo#655973, bgo#572697.
  + Updated translations.
- Drop pkgconfig(gconf-2.0) BuildRequires, as the code has been
  ported to GSettings.
- Replace the gconf schema handling with gsettings one.
* Fri Aug  5 2011 dimstar@opensuse.org
- Update to version 2.90.0:
  + Changes for GNOME 3 support:
  - Port from poptOption to GOptionEntry
  - Replace deprecated GTK+ symbols
  - Remove libgnome and libgnomeui dependency
  - Use Gio instead GnomeVfs
  - Replace Gdk drawing with Cairo
  - Port from BonoboUI to GtkUIManager
  - Remove custom print widgets
  - Port from libgnomeprint to GtkPrint
  - Port to GTK+ 3
  - Rename the shared libray for parallel installability
  + New Features and UI Improvements:
  - Improve About dialog
  - Add relative offset jumping with + and - in 'Go to Byte'
  - Use double buffering for drawing, reducing flicker
  + Bug fixes:
  - Convert po files to UTF-8
  - Fix various compiler warnings
  - Fix xsltproc warnings
  - Fix the order of LDADD
  - Fix build with stricter linker on latest Fedora
  - Fix gnome-doc-utils support
  - Modernize autotools configuration
  - Use upstream gettext instead the glib one
  - Fix regression with close on save confirmation
  - Avoid showing status message on an already destroyed window
  - Update overview when deleting a character with the 'DEL' key
  + Bugs fixed: bgo#333819, bgo#445053, bgo#508563, bgo#547882,
    bgo#548438, bgo#570688, bgo#571892, bgo#584006, bgo#590995,
    bgo#590996, bgo#597683, bgo#597684, bgo#597685, bgo#597687,
    bgo#597688, bgo#608275, bgo#608284, bgo#609277, bgo#609548,
    bgo#612693, bgo#612885, bgo#630377.
  + Updated translations.
- Remove libgnomeui-devel and libgnomeprintui-devel BuildRequires.
- Add pkgconfig(atk), pkgconfig(gail-3.0), pkgconfig(gconf-2.0),
  pkgconfig(gio-2.0) and pkgconfig(gtk+-3.0) BuildRequires.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Feb 22 2009 vuntz@novell.com
- Update to version 2.24.0:
  + set G_LOG_DOMAIN for the shared libgtkhex library so that
    warning messages use the right domain
  + fix background between the hex and ascii widgets becoming dark
    black. (bgo#527279)
  + Fix the allocation code to allocate the child widgets relative
    to the GtkHex allocation.x and allocation.y coordinates instead
    of (0,0). (bgo#527272)
  + fix a bug where the selection would always start at 0 if the
    user only used the keyboard
  + Update the About Dialog to use the application icon.
    (bgo#520983)
  + fix ghex2 printing g_warning on startup because it uses a
    deprecated API (bgo#564371)
  + remove unused variables (bgo#564375)
  + make desktop files follow freedesktop spec (bgo#568023)
  + Fix an off-by-one error in reporting the number of bytes
    selected in the status bar
  + GObject type ids should be instances of GType, not of guint
- Remove BuildRequires: gail-devel (provided by gtk2-devel),
  gnome-common, gnutls-devel, libglade2-devel, libwnck-devel,
  perl-XML-Parser, scrollkeeper
- Remove check for old versions of openSUSE.
- Do not set DocPath in the desktop file (not needed by yelp).
- Remove call to autoreconf.
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Mon Jan 19 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Tue Sep  2 2008 mboman@novell.com
- Update to version 2.22.0:
  + Cosmetic version bump
* Thu May  8 2008 rodrigo@suse.de
- Upstream remaining patch
* Mon Mar 31 2008 vuntz@suse.de
- Update to version 2.21.92 (too many changes to list here)
- Remove ghex_60921.diff (fixed upstream), ghex_60922.diff (fixed
  upstream), ghex-search-crash.patch (fixed upstream).
- Remove workaround for no translations.
- Add gnome-doc-utils-devel buildrequires.
- Stop using %%run_ldconfig and call ldconfig.
* Thu Mar 13 2008 sbrabec@suse.cz
- Custom look'n'feel gconf keys moved to gconf2-branding-openSUSE.
* Thu Mar  6 2008 maw@suse.de
- Fix the build when against newer versions of intltool.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Mon Sep  3 2007 sbrabec@suse.cz
- Fixed crash for empty search string (GNOME#473208).
* Thu Aug  9 2007 maw@suse.de
- Fix up the lang subpackage.
* Tue Aug  7 2007 mauro@suse.de
- Split out a -lang subpackage
- Add %%fdupes stuff
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Wed Jan  3 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
- Created ghex-devel subpackage.
* Tue Sep 19 2006 jhargadon@suse.de
- update to version 2.8.2
- translation updates
* Wed Apr 19 2006 sbrabec@suse.cz
- Fixed crash in search (#155494).
* Wed Apr 19 2006 sbrabec@suse.cz
- I18N fix.
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Feb 22 2005 ro@suse.de
- change category to build
* Fri Feb 18 2005 sbrabec@suse.cz
- Updated to version 2.8.1.
* Tue Nov  2 2004 ro@suse.de
- locale rename: no -> nb
* Wed Aug 25 2004 clahey@suse.de
- Cache the ghex help and show ghex in khelpcenter.
* Fri Jul 16 2004 shprasad@suse.de
- Fixes bug #60916 (Fix given by smadduri@novell.com)
  Corrects Typo mistakes in status messages
- Fixes bug #60919 (Fix given by smadduri@novell.com)
  Status bar resets upon file close
- Fixes bug #60921 (Fix given by smadduri@novell.com)
  Removed ellipses in Menu option "Character Table"
- Fixes bug #60922 (Fix given by smadduri@novell.com)
  Removes Duplicate accelerator keys for Edit menu options.
- Fixes bug #60918 (Fix given by smadduri@novell.com)
  Avoids Crashing when trying to open /proc files.
* Wed Jun 23 2004 shprasad@suse.de
- Fixes bug #60089 (Fix given by smadduri@novell.com)
  Changed The Title Pattern.
* Wed Jun 23 2004 shprasad@suse.de
- Fixes bug #59873 (Fix given by smadduri@novell.com)
  Changed the default Fonts.
* Wed May  5 2004 sbrabec@suse.cz
- Updated to version 2.6.0 (GNOME 2.6).
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
* Fri Feb 20 2004 sbrabec@suse.cz
- Fixed PreReq.
* Thu Feb 12 2004 sbrabec@suse.cz
- Updated to version 2.4.1.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.4.0.1 (GNOME 2.4).
* Sun Sep 14 2003 adrian@suse.de
- add Editor Category
* Mon Aug 18 2003 sbrabec@suse.cz
- Updated to version 2.2.1 (GNOME2).
* Wed May 28 2003 sbrabec@suse.cz
- Include all doc and omf files info package.
* Tue May 27 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
* Tue Oct 22 2002 hhetter@suse.de
- added libxslt to #neededforbuild to get scrollkeeper to run
- removed wrong docdir
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Mon May 27 2002 ro@suse.de
- removed gpc from neededforbuild
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Fri Nov 30 2001 ro@suse.de
- changed neededforbuild <docbktls> to <docbook-toys>
* Tue Nov 20 2001 ro@suse.de
- added freetype2 to neededforbuild
* Fri Jun 15 2001 hhetter@suse.de
- update to 1.2.1
- use bz2
- added scrollkeeper to neededforbuild
- added suse_update_config
* Tue Mar 27 2001 ro@suse.de
- changed neededforbuild <docbkdsl> to <docbook-dsssl-stylesheets>
* Thu Mar 22 2001 hhetter@suse.de
- updated to version 1.2 (RC1)
- specfile improvements
* Wed Mar 14 2001 ro@suse.de
- changed neededforbuild <docbk_4> to <docbook_4>
* Thu Feb 22 2001 hhetter@suse.de
- initial build
- tested on 7.1 in GNOME1.4 Environment
